#include "importcrewlounge.h"
#include "src/database/adatabase.h"
#include "src/opl.h"
#include "src/testing/importCrewlounge/processpilots.h"
#include "src/testing/importCrewlounge/processaircraft.h"
#include "src/testing/importCrewlounge/processflights.h"
#include "src/functions/areadcsv.h"

namespace ImportCrewlounge
{

void exec(const QString &csv_file_path)
{
    // Inhibit HomeWindow Updating
    QSignalBlocker blocker(aDB);

    // Prepare database and set up exclusive transaction for mass commit
    QSqlQuery q;
    q.prepare(QStringLiteral("BEGIN EXCLUSIVE TRANSACTION"));
    q.exec();

    // Read from CSV and remove first line (headers)
    auto raw_csv_data = aReadCsvAsRows(csv_file_path);
    raw_csv_data.removeFirst();

    // Process Pilots
    auto proc_pilots = ProcessPilots(raw_csv_data);
    proc_pilots.init();
    const auto p_maps = proc_pilots.getProcessedPilotMaps();

    for (const auto & pilot : p_maps) {
        APilotEntry pe(pilot);
        pe.setPosition(DataPosition(Opl::Db::TABLE_PILOTS, pilot.value(Opl::Db::PILOTS_ROWID).toInt()));
        aDB->commit(pe);
    }

    // Process Tails
    auto proc_tails = ProcessAircraft(raw_csv_data);
    proc_tails.init();
    const auto t_maps = proc_tails.getProcessedTailMaps();

    for (const auto& tail : t_maps) {
        ATailEntry te(tail);
        te.setPosition(DataPosition(Opl::Db::TABLE_TAILS, tail.value(Opl::Db::PILOTS_ROWID).toInt()));
        aDB->commit(te);
    }

    auto proc_flights = ProcessFlights(raw_csv_data,
                                       proc_pilots.getProcessedPilotsIds(),
                                       proc_tails.getProcessedTailIds());
    proc_flights.init();
    const auto flights = proc_flights.getProcessedFlights();



    for (const auto &flight : flights) {
        AFlightEntry fe(flight);
        aDB->commit(fe);
    }

    // Commit the exclusive transaction
    q.prepare(QStringLiteral("COMMIT"));
    q.exec();

    // destroy blocker
    blocker.unblock();
    emit aDB->dataBaseUpdated();
}
}// namespace ImportCrewLongue
